CVS commit: src/sys/arch/arm/iomd

2021-02-03 Thread Tetsuya Isaki
Module Name:src
Committed By:   isaki
Date:   Wed Feb  3 14:22:21 UTC 2021

Modified Files:
src/sys/arch/arm/iomd: vidcaudio.c

Log Message:
Remove a comment no longer correct.
Because halt_output is no longer called from an interrupt context,
but that does not mean it's better to put this back to halt_output.


To generate a diff of this commit:
cvs rdiff -u -r1.60 -r1.61 src/sys/arch/arm/iomd/vidcaudio.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/arm/iomd/vidcaudio.c
diff -u src/sys/arch/arm/iomd/vidcaudio.c:1.60 src/sys/arch/arm/iomd/vidcaudio.c:1.61
--- src/sys/arch/arm/iomd/vidcaudio.c:1.60	Sun Feb 23 04:02:45 2020
+++ src/sys/arch/arm/iomd/vidcaudio.c	Wed Feb  3 14:22:21 2021
@@ -1,4 +1,4 @@
-/*	$NetBSD: vidcaudio.c,v 1.60 2020/02/23 04:02:45 isaki Exp $	*/
+/*	$NetBSD: vidcaudio.c,v 1.61 2021/02/03 14:22:21 isaki Exp $	*/
 
 /*
  * Copyright (c) 1995 Melvin Tang-Richardson
@@ -65,7 +65,7 @@
 
 #include 	/* proc.h */
 
-__KERNEL_RCSID(0, "$NetBSD: vidcaudio.c,v 1.60 2020/02/23 04:02:45 isaki Exp $");
+__KERNEL_RCSID(0, "$NetBSD: vidcaudio.c,v 1.61 2021/02/03 14:22:21 isaki Exp $");
 
 #include 
 #include/* autoconfig functions */
@@ -293,11 +293,6 @@ vidcaudio_close(void *addr)
 
 	DPRINTF(("DEBUG: vidcaudio_close called\n"));
 	sc = addr;
-	/*
-	 * We do this here rather than in vidcaudio_halt_output()
-	 * because the latter can be called from interrupt context
-	 * (audio_pint()->audio_clear()->vidcaudio_halt_output()).
-	 */
 	if (sc->sc_ppages != NULL) {
 		free(sc->sc_ppages, M_DEVBUF);
 		sc->sc_ppages = NULL;



CVS commit: src/sys/arch/arm/iomd

2020-11-21 Thread Nick Hudson
Module Name:src
Committed By:   skrll
Date:   Sat Nov 21 19:52:56 UTC 2020

Modified Files:
src/sys/arch/arm/iomd: iomd_irq.S

Log Message:
Adjust code and register usage so that r4 and r5 are preserved as
cur{cpu,lwp} respectively as required by the change to make ASTs
operate per-LWP rather than per-CPU.  These registers are used by
DO_AST_AND_RESTORE_ALIGNMENT_FAULTS expecting this usage.

XXX untested


To generate a diff of this commit:
cvs rdiff -u -r1.17 -r1.18 src/sys/arch/arm/iomd/iomd_irq.S

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/arm/iomd/iomd_irq.S
diff -u src/sys/arch/arm/iomd/iomd_irq.S:1.17 src/sys/arch/arm/iomd/iomd_irq.S:1.18
--- src/sys/arch/arm/iomd/iomd_irq.S:1.17	Sat Nov 21 09:36:26 2020
+++ src/sys/arch/arm/iomd/iomd_irq.S	Sat Nov 21 19:52:56 2020
@@ -1,4 +1,4 @@
-/*	$NetBSD: iomd_irq.S,v 1.17 2020/11/21 09:36:26 skrll Exp $	*/
+/*	$NetBSD: iomd_irq.S,v 1.18 2020/11/21 19:52:56 skrll Exp $	*/
 
 /*
  * Copyright (c) 1994-1998 Mark Brinicombe.
@@ -100,10 +100,11 @@ AST_ALIGNMENT_FAULT_LOCALS
  * Register usage
  *
  *  r4  - Address of cpu_info
- *  r5  - Address of ffs table
+ *  r5  - Address of curlwp
  *  r6  - Address of current handler
  *  r7  - Pointer to handler pointer list
  *  r8  - Current IRQ requests.
+ *  r9  - scratch
  *  r10 - Base address of IOMD
  *  r11 - IRQ requests still to service.
  */
@@ -118,7 +119,7 @@ ASENTRY_NP(irq_entry)
 	sub	lr, lr, #0x0004	/* Adjust the lr */
 
 	PUSHFRAMEINSVC			/* Push an interrupt frame */
-	ENABLE_ALIGNMENT_FAULTS
+	ENABLE_ALIGNMENT_FAULTS		/* puts cur{cpu,lwp} in r4/r5 */
 
 	str	r7, [sp, #TF_FILL]	/* save r7 */
 
@@ -212,22 +213,20 @@ Lfind_highest_ipl:
 	bic	r0, r0, #I32_bit
 	msr	cpsr_all, r0
 
-	ldr	r7, Lirqhandlers
-
 	/*
 	 * take a copy of the IRQ request so that we can strip bits out of it
 	 * note that we only use 24 bits with iomd2 chips
 	 */
-	ldr	r5, Larm7500_ioc_found
-	ldr	r5, [r5]			/* get the flag  */
-	cmp	r5, #0
+	ldr	r7, Larm7500_ioc_found
+	ldr	r7, [r7]			/* get the flag  */
+	cmp	r7, #0
 	movne	r11, r8/* ARM7500  -> copy all bits   */
 	biceq	r11, r8, #0xff00		/* !ARM7500 -> only use 24 bit */
 
 	/* ffs routine to find first irq to service */
 	/* standard trick to isolate bottom bit in a0 or 0 if a0 = 0 on entry */
-	rsb	r5, r11, #0
-	ands	r10, r11, r5
+	rsb	r7, r11, #0
+	ands	r10, r11, r7
 
 	/*
 	 * now r10 has at most 1 set bit, call this X
@@ -235,22 +234,22 @@ Lfind_highest_ipl:
 	 */
 	beq	exitirq
 irqloop:
-	adr	r5, Lirq_ffs_table
+	ldr	r6, Lirqhandlers
+	adr	r7, Lirq_ffs_table
 	/*
 	 * at this point:
-	 *	r5 = address of ffs table
-	 *	r7 = address of irq handlers table
+	 * 	r6 = address of irq handlers table
+	 *	r7 = address of ffs table
 	 *	r8 = irq request
 	 *	r10 = bit of irq to be serviced
 	 *	r11 = bitmask of IRQ's to service
 	 */
-
 	/* find the set bit */
 	orr	r9, r10, r10, lsl #4	/* X * 0x11 */
 	orr	r9, r9, r9, lsl #6	/* X * 0x451 */
 	rsb	r9, r9, r9, lsl #16	/* X * 0x0450fbaf */
 	/* fetch the bit number */
-	ldrb	r9, [r5, r9, lsr #26 ]
+	ldrb	r9, [r7, r9, lsr #26 ]
 
 	/*
 	 * r9 = irq to service
@@ -265,7 +264,7 @@ irqloop:
 	 *	- unsetting of the irq bit in r11
 	 *	- irq stats (if enabled) also get put in the mix
 	 */
-	ldr	r6, [r7, r9, lsl #2]	/* Get address of first handler structure */
+	ldr	r6, [r6, r9, lsl #2]	/* Get address of first handler structure */
 
 	teq	r6, #0x		/* Do we have a handler */
 	moveq	r0, r8			/* IRQ requests as arg 0 */
@@ -301,6 +300,7 @@ irqchainloop:
 	ldr	r0, [r6, #(IH_ARG)]	/* Get argument pointer */
 	teq	r0, #0x		/* If arg is zero pass stack frame */
 	addeq	r0, sp, #8		/* ... stack frame [XXX needs care] */
+
 	mov	lr, pc			/* return address */
 	ldr	pc, [r6, #(IH_FUNC)]	/* Call handler */
 
@@ -313,8 +313,8 @@ irqchainloop:
 	bne	irqchainloop
 nextirq:
 	/* Check for next irq */
-	rsb	r5, r11, #0
-	ands	r10, r11, r5
+	rsb	r7, r11, #0
+	ands	r10, r11, r7
 	/* check if there are anymore irq's to service */
 	bne 	irqloop
 
@@ -326,10 +326,6 @@ exitirq:
 
 	bl	_C_LABEL(irq_setmasks)
 
-#if __HAVE_FAST_SOFTINTS
-	bl	_C_LABEL(dosoftints)	/* Handle the soft interrupts */
-#endif
-
 	/* Kill IRQ's in preparation for exit */
 mrs r0, cpsr
 orr r0, r0, #(I32_bit)



CVS commit: src/sys/arch/arm/iomd

2020-11-20 Thread Jason R Thorpe
Module Name:src
Committed By:   thorpej
Date:   Fri Nov 20 18:18:51 UTC 2020

Modified Files:
src/sys/arch/arm/iomd: iomd_irqhandler.c iomdkbc.c

Log Message:
malloc(9) -> kmem(9)


To generate a diff of this commit:
cvs rdiff -u -r1.23 -r1.24 src/sys/arch/arm/iomd/iomd_irqhandler.c
cvs rdiff -u -r1.6 -r1.7 src/sys/arch/arm/iomd/iomdkbc.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/arm/iomd/iomd_irqhandler.c
diff -u src/sys/arch/arm/iomd/iomd_irqhandler.c:1.23 src/sys/arch/arm/iomd/iomd_irqhandler.c:1.24
--- src/sys/arch/arm/iomd/iomd_irqhandler.c:1.23	Sun Nov 10 21:16:23 2019
+++ src/sys/arch/arm/iomd/iomd_irqhandler.c	Fri Nov 20 18:18:51 2020
@@ -1,4 +1,4 @@
-/*	$NetBSD: iomd_irqhandler.c,v 1.23 2019/11/10 21:16:23 chs Exp $	*/
+/*	$NetBSD: iomd_irqhandler.c,v 1.24 2020/11/20 18:18:51 thorpej Exp $	*/
 
 /*
  * Copyright (c) 1994-1998 Mark Brinicombe.
@@ -40,14 +40,14 @@
  */
 
 #include 
-__KERNEL_RCSID(0, "$NetBSD: iomd_irqhandler.c,v 1.23 2019/11/10 21:16:23 chs Exp $");
+__KERNEL_RCSID(0, "$NetBSD: iomd_irqhandler.c,v 1.24 2020/11/20 18:18:51 thorpej Exp $");
 
 #include "opt_irqstats.h"
 
 #include 
 #include 
 #include 
-#include 
+#include 
 
 #include 
 #include 
@@ -346,7 +346,7 @@ intr_claim(int irq, int level, const cha
 {
 	irqhandler_t *ih;
 
-	ih = malloc(sizeof(*ih), M_DEVBUF, M_WAITOK);
+	ih = kmem_alloc(sizeof(*ih), KM_SLEEP);
 	ih->ih_level = level;
 	ih->ih_name = name;
 	ih->ih_func = ih_func;
@@ -354,7 +354,7 @@ intr_claim(int irq, int level, const cha
 	ih->ih_flags = 0;
 
 	if (irq_claim(irq, ih) != 0) {
-		free(ih, M_DEVBUF);
+		kmem_free(ih, sizeof(*ih));
 		return NULL;
 	}
 	return ih;
@@ -367,7 +367,7 @@ intr_release(void *arg)
 	irqhandler_t *ih = (irqhandler_t *)arg;
 
 	if (irq_release(ih->ih_num, ih) == 0) {
-		free(ih, M_DEVBUF);
+		kmem_free(ih, sizeof(*ih));
 		return 0 ;
 	}
 	return 1;

Index: src/sys/arch/arm/iomd/iomdkbc.c
diff -u src/sys/arch/arm/iomd/iomdkbc.c:1.6 src/sys/arch/arm/iomd/iomdkbc.c:1.7
--- src/sys/arch/arm/iomd/iomdkbc.c:1.6	Sun Nov 10 21:16:23 2019
+++ src/sys/arch/arm/iomd/iomdkbc.c	Fri Nov 20 18:18:51 2020
@@ -1,4 +1,4 @@
-/* $NetBSD: iomdkbc.c,v 1.6 2019/11/10 21:16:23 chs Exp $ */
+/* $NetBSD: iomdkbc.c,v 1.7 2020/11/20 18:18:51 thorpej Exp $ */
 
 /*-
  * Copyright (c) 2004 Ben Harris
@@ -28,11 +28,11 @@
  */
 
 #include 
-__KERNEL_RCSID(0, "$NetBSD: iomdkbc.c,v 1.6 2019/11/10 21:16:23 chs Exp $");
+__KERNEL_RCSID(0, "$NetBSD: iomdkbc.c,v 1.7 2020/11/20 18:18:51 thorpej Exp $");
 
 #include 
 #include 
-#include 
+#include 
 #include 
 
 #include 
@@ -133,8 +133,8 @@ iomdkbc_attach(device_t parent, device_t
 			/* Have an iomdkbc as console.  Assume it's this one.*/
 			t = _cntag;
 		} else {
-			t = malloc(sizeof(struct iomdkbc_internal), M_DEVBUF,
-			M_WAITOK | M_ZERO);
+			t = kmem_zalloc(sizeof(struct iomdkbc_internal),
+			KM_SLEEP);
 			t->t_haveport[PCKBPORT_KBD_SLOT] = 1;
 			t->t_iot = ka->ka_iot;
 			t->t_ioh[PCKBPORT_KBD_SLOT] = ka->ka_ioh;
@@ -151,8 +151,8 @@ iomdkbc_attach(device_t parent, device_t
 
 	if (strcmp(pa->pa_name, "opms") == 0) {
 		if (t == NULL) {
-			t = malloc(sizeof(struct iomdkbc_internal), M_DEVBUF,
-			M_WAITOK | M_ZERO);
+			t = kmem_zalloc(sizeof(struct iomdkbc_internal),
+			KM_SLEEP);
 		}
 		t->t_haveport[PCKBPORT_AUX_SLOT] = 1;
 		t->t_iot = pa->pa_iot;



CVS commit: src/sys/arch/arm/iomd

2016-12-13 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Tue Dec 13 20:18:06 UTC 2016

Modified Files:
src/sys/arch/arm/iomd: vidcaudio.c

Log Message:
back to passing device_t


To generate a diff of this commit:
cvs rdiff -u -r1.54 -r1.55 src/sys/arch/arm/iomd/vidcaudio.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/arm/iomd/vidcaudio.c
diff -u src/sys/arch/arm/iomd/vidcaudio.c:1.54 src/sys/arch/arm/iomd/vidcaudio.c:1.55
--- src/sys/arch/arm/iomd/vidcaudio.c:1.54	Fri Dec  9 08:26:47 2016
+++ src/sys/arch/arm/iomd/vidcaudio.c	Tue Dec 13 15:18:06 2016
@@ -1,4 +1,4 @@
-/*	$NetBSD: vidcaudio.c,v 1.54 2016/12/09 13:26:47 christos Exp $	*/
+/*	$NetBSD: vidcaudio.c,v 1.55 2016/12/13 20:18:06 christos Exp $	*/
 
 /*
  * Copyright (c) 1995 Melvin Tang-Richardson
@@ -65,7 +65,7 @@
 
 #include 	/* proc.h */
 
-__KERNEL_RCSID(0, "$NetBSD: vidcaudio.c,v 1.54 2016/12/09 13:26:47 christos Exp $");
+__KERNEL_RCSID(0, "$NetBSD: vidcaudio.c,v 1.55 2016/12/13 20:18:06 christos Exp $");
 
 #include 
 #include/* autoconfig functions */
@@ -270,8 +270,7 @@ vidcaudio_attach(device_t parent, device
 
 	beepdev = audio_attach_mi(_hw_if, sc, self);
 #if NPCKBD > 0
-	int unit = device_unit(beepdev);
-	pckbd_hookup_bell(audiobell, );
+	pckbd_hookup_bell(audiobell, beepdev);
 #endif
 }
 



CVS commit: src/sys/arch/arm/iomd

2016-12-09 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Fri Dec  9 13:26:47 UTC 2016

Modified Files:
src/sys/arch/arm/iomd: vidcaudio.c

Log Message:
audiobell now only needs the unit.


To generate a diff of this commit:
cvs rdiff -u -r1.53 -r1.54 src/sys/arch/arm/iomd/vidcaudio.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/arm/iomd/vidcaudio.c
diff -u src/sys/arch/arm/iomd/vidcaudio.c:1.53 src/sys/arch/arm/iomd/vidcaudio.c:1.54
--- src/sys/arch/arm/iomd/vidcaudio.c:1.53	Sat Oct 25 06:58:12 2014
+++ src/sys/arch/arm/iomd/vidcaudio.c	Fri Dec  9 08:26:47 2016
@@ -1,4 +1,4 @@
-/*	$NetBSD: vidcaudio.c,v 1.53 2014/10/25 10:58:12 skrll Exp $	*/
+/*	$NetBSD: vidcaudio.c,v 1.54 2016/12/09 13:26:47 christos Exp $	*/
 
 /*
  * Copyright (c) 1995 Melvin Tang-Richardson
@@ -65,7 +65,7 @@
 
 #include 	/* proc.h */
 
-__KERNEL_RCSID(0, "$NetBSD: vidcaudio.c,v 1.53 2014/10/25 10:58:12 skrll Exp $");
+__KERNEL_RCSID(0, "$NetBSD: vidcaudio.c,v 1.54 2016/12/09 13:26:47 christos Exp $");
 
 #include 
 #include/* autoconfig functions */
@@ -270,7 +270,8 @@ vidcaudio_attach(device_t parent, device
 
 	beepdev = audio_attach_mi(_hw_if, sc, self);
 #if NPCKBD > 0
-	pckbd_hookup_bell(audiobell, beepdev);
+	int unit = device_unit(beepdev);
+	pckbd_hookup_bell(audiobell, );
 #endif
 }
 



CVS commit: src/sys/arch/arm/iomd

2014-09-21 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Sun Sep 21 15:46:44 UTC 2014

Modified Files:
src/sys/arch/arm/iomd: iomd_irqhandler.c

Log Message:
fix leak.


To generate a diff of this commit:
cvs rdiff -u -r1.20 -r1.21 src/sys/arch/arm/iomd/iomd_irqhandler.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/arm/iomd/iomd_irqhandler.c
diff -u src/sys/arch/arm/iomd/iomd_irqhandler.c:1.20 src/sys/arch/arm/iomd/iomd_irqhandler.c:1.21
--- src/sys/arch/arm/iomd/iomd_irqhandler.c:1.20	Wed Mar 26 15:44:51 2014
+++ src/sys/arch/arm/iomd/iomd_irqhandler.c	Sun Sep 21 11:46:44 2014
@@ -1,4 +1,4 @@
-/*	$NetBSD: iomd_irqhandler.c,v 1.20 2014/03/26 19:44:51 christos Exp $	*/
+/*	$NetBSD: iomd_irqhandler.c,v 1.21 2014/09/21 15:46:44 christos Exp $	*/
 
 /*
  * Copyright (c) 1994-1998 Mark Brinicombe.
@@ -40,7 +40,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: iomd_irqhandler.c,v 1.20 2014/03/26 19:44:51 christos Exp $);
+__KERNEL_RCSID(0, $NetBSD: iomd_irqhandler.c,v 1.21 2014/09/21 15:46:44 christos Exp $);
 
 #include opt_irqstats.h
 
@@ -356,8 +356,10 @@ intr_claim(int irq, int level, const cha
 	ih-ih_arg = ih_arg;
 	ih-ih_flags = 0;
 
-	if (irq_claim(irq, ih) != 0)
+	if (irq_claim(irq, ih) != 0) {
+		free(ih, M_DEVBUF);
 		return NULL;
+	}
 	return ih;
 }
 



CVS commit: src/sys/arch/arm/iomd

2014-03-26 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Wed Mar 26 19:44:51 UTC 2014

Modified Files:
src/sys/arch/arm/iomd: iomd_irqhandler.c

Log Message:
Add missing ;


To generate a diff of this commit:
cvs rdiff -u -r1.19 -r1.20 src/sys/arch/arm/iomd/iomd_irqhandler.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/arm/iomd/iomd_irqhandler.c
diff -u src/sys/arch/arm/iomd/iomd_irqhandler.c:1.19 src/sys/arch/arm/iomd/iomd_irqhandler.c:1.20
--- src/sys/arch/arm/iomd/iomd_irqhandler.c:1.19	Wed Mar 26 04:52:00 2014
+++ src/sys/arch/arm/iomd/iomd_irqhandler.c	Wed Mar 26 15:44:51 2014
@@ -1,4 +1,4 @@
-/*	$NetBSD: iomd_irqhandler.c,v 1.19 2014/03/26 08:52:00 christos Exp $	*/
+/*	$NetBSD: iomd_irqhandler.c,v 1.20 2014/03/26 19:44:51 christos Exp $	*/
 
 /*
  * Copyright (c) 1994-1998 Mark Brinicombe.
@@ -40,7 +40,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: iomd_irqhandler.c,v 1.19 2014/03/26 08:52:00 christos Exp $);
+__KERNEL_RCSID(0, $NetBSD: iomd_irqhandler.c,v 1.20 2014/03/26 19:44:51 christos Exp $);
 
 #include opt_irqstats.h
 
@@ -180,7 +180,7 @@ irq_claim(int irq, irqhandler_t *handler
 	/* Get the interrupt name from the head of the list */
 	char *iptr = _intrnames + (irq * 14);
 	if (handler-ih_name) {
-		strlcpy(iptr, handler-ih_name, 14)
+		strlcpy(iptr, handler-ih_name, 14);
 	} else {
 		snprintf(iptr, 14, irq %2d , irq);
 	}



CVS commit: src/sys/arch/arm/iomd

2014-01-21 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Tue Jan 21 19:31:57 UTC 2014

Modified Files:
src/sys/arch/arm/iomd: vidcvideo.c

Log Message:
tuck in variables that are only used in the #if 0 block


To generate a diff of this commit:
cvs rdiff -u -r1.43 -r1.44 src/sys/arch/arm/iomd/vidcvideo.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/arm/iomd/vidcvideo.c
diff -u src/sys/arch/arm/iomd/vidcvideo.c:1.43 src/sys/arch/arm/iomd/vidcvideo.c:1.44
--- src/sys/arch/arm/iomd/vidcvideo.c:1.43	Mon May 14 06:38:08 2012
+++ src/sys/arch/arm/iomd/vidcvideo.c	Tue Jan 21 14:31:57 2014
@@ -1,4 +1,4 @@
-/* $NetBSD: vidcvideo.c,v 1.43 2012/05/14 10:38:08 skrll Exp $ */
+/* $NetBSD: vidcvideo.c,v 1.44 2014/01/21 19:31:57 christos Exp $ */
 
 /*
  * Copyright (c) 2001 Reinoud Zandijk
@@ -30,7 +30,7 @@
 
 #include sys/cdefs.h			/* RCS ID  Copyright macro defns */
 
-__KERNEL_RCSID(0, $NetBSD: vidcvideo.c,v 1.43 2012/05/14 10:38:08 skrll Exp $);
+__KERNEL_RCSID(0, $NetBSD: vidcvideo.c,v 1.44 2014/01/21 19:31:57 christos Exp $);
 
 #include sys/param.h
 #include sys/systm.h
@@ -784,24 +784,23 @@ set_curpos(struct vidcvideo_softc *sc, s
 static void vv_copyrows(void *id, int srcrow, int dstrow, int nrows)
 {
 	struct rasops_info *ri = id;
-	int height, offset, size;
-	int scrollup, scrolldown;
+	int height, size;
 	unsigned char *src, *dst;
 	struct vcons_screen *scr = ri-ri_hw;
 	struct fb_devconfig *dc = (struct fb_devconfig *) (scr-scr_cookie);
 
 	/* All movements are done in multiples of character heigths */
 	height = ri-ri_font-fontheight * nrows;
-	offset = (srcrow - dstrow) * ri-ri_yscale;
 	size   = height * ri-ri_stride;
 
 	/* check if we are full screen scrolling */
-	scrollup   = (srcrow + nrows = ri-ri_rows);
-	scrolldown = (dstrow + nrows = ri-ri_rows);
 
 #if 0
+	int scrollup   = (srcrow + nrows = ri-ri_rows);
+	int scrolldown = (dstrow + nrows = ri-ri_rows);
 	if ((scrollup || scrolldown) 
 	(videomemory.vidm_type == VIDEOMEM_TYPE_VRAM)) {
+		int offset = (srcrow - dstrow) * ri-ri_yscale;
 		ri-ri_bits = vidcvideo_hwscroll(offset);
 		vidcvideo_progr_scroll();	/* sadistic ; shouldnt this be on vsync? */
 



CVS commit: src/sys/arch/arm/iomd

2013-08-18 Thread Matt Thomas
Module Name:src
Committed By:   matt
Date:   Sun Aug 18 16:09:50 UTC 2013

Modified Files:
src/sys/arch/arm/iomd: iomd_fiq.S

Log Message:
Fix typo


To generate a diff of this commit:
cvs rdiff -u -r1.4 -r1.5 src/sys/arch/arm/iomd/iomd_fiq.S

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/arm/iomd/iomd_fiq.S
diff -u src/sys/arch/arm/iomd/iomd_fiq.S:1.4 src/sys/arch/arm/iomd/iomd_fiq.S:1.5
--- src/sys/arch/arm/iomd/iomd_fiq.S:1.4	Sun Aug 18 06:28:18 2013
+++ src/sys/arch/arm/iomd/iomd_fiq.S	Sun Aug 18 16:09:50 2013
@@ -1,4 +1,4 @@
-/*	$NetBSD: iomd_fiq.S,v 1.4 2013/08/18 06:28:18 matt Exp $	*/
+/*	$NetBSD: iomd_fiq.S,v 1.5 2013/08/18 16:09:50 matt Exp $	*/
 
 /*
  * Copyright (c) 1994-1996 Mark Brinicombe.
@@ -76,7 +76,7 @@ ENTRY_NP(floppy_read_fiq)
 	bne	_C_LABEL(floppy_read_fiq)
 #endif
 	subs	pc, lr, #0x0004
-END(_floppy_read_fiq)
+END(floppy_read_fiq)
 
 	.global	_C_LABEL(floppy_read_fiq_end)
 _C_LABEL(floppy_read_fiq_end):



CVS commit: src/sys/arch/arm/iomd

2013-08-12 Thread Matt Thomas
Module Name:src
Committed By:   matt
Date:   Mon Aug 12 16:07:03 UTC 2013

Modified Files:
src/sys/arch/arm/iomd: iomd_fiq.S

Log Message:
Convert to unified syntax


To generate a diff of this commit:
cvs rdiff -u -r1.2 -r1.3 src/sys/arch/arm/iomd/iomd_fiq.S

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/arm/iomd/iomd_fiq.S
diff -u src/sys/arch/arm/iomd/iomd_fiq.S:1.2 src/sys/arch/arm/iomd/iomd_fiq.S:1.3
--- src/sys/arch/arm/iomd/iomd_fiq.S:1.2	Thu Dec 20 01:20:23 2001
+++ src/sys/arch/arm/iomd/iomd_fiq.S	Mon Aug 12 16:07:03 2013
@@ -1,4 +1,4 @@
-/*	$NetBSD: iomd_fiq.S,v 1.2 2001/12/20 01:20:23 thorpej Exp $	*/
+/*	$NetBSD: iomd_fiq.S,v 1.3 2013/08/12 16:07:03 matt Exp $	*/
 
 /*
  * Copyright (c) 1994-1996 Mark Brinicombe.
@@ -69,7 +69,7 @@ ENTRY_NP(floppy_read_fiq)
 	ldrb	r8, [r12]
 	strb	r8, [r11], #0x0001
 #ifndef NOFDFIQLOOPS
-	subeqs	pc, lr, #0x0004
+	subseq	pc, lr, #0x0004
 	ldrb	r8, [r9]
 	tst	r8, #0x01
 	addne	r13, r13, #0x0001
@@ -99,7 +99,7 @@ ENTRY_NP(floppy_write_fiq)
 	ldrb	r8, [r11], #0x0001
 	strb	r8, [r12]
 #ifndef NOFDFIQLOOPS
-	subeqs	pc, lr, #0x0004
+	subseq	pc, lr, #0x0004
 	ldrb	r8, [r9]
 	tst	r8, #0x01
 	addne	r13, r13, #0x0001



CVS commit: src/sys/arch/arm/iomd

2012-10-10 Thread Nick Hudson
Module Name:src
Committed By:   skrll
Date:   Wed Oct 10 22:00:22 UTC 2012

Modified Files:
src/sys/arch/arm/iomd: iomd.c vidcaudio.c

Log Message:
Use device_xname.

From chuq.


To generate a diff of this commit:
cvs rdiff -u -r1.20 -r1.21 src/sys/arch/arm/iomd/iomd.c
cvs rdiff -u -r1.50 -r1.51 src/sys/arch/arm/iomd/vidcaudio.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/arm/iomd/iomd.c
diff -u src/sys/arch/arm/iomd/iomd.c:1.20 src/sys/arch/arm/iomd/iomd.c:1.21
--- src/sys/arch/arm/iomd/iomd.c:1.20	Mon May 14 11:05:29 2012
+++ src/sys/arch/arm/iomd/iomd.c	Wed Oct 10 22:00:22 2012
@@ -1,4 +1,4 @@
-/*	$NetBSD: iomd.c,v 1.20 2012/05/14 11:05:29 skrll Exp $	*/
+/*	$NetBSD: iomd.c,v 1.21 2012/10/10 22:00:22 skrll Exp $	*/
 
 /*
  * Copyright (c) 1996-1997 Mark Brinicombe.
@@ -43,7 +43,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: iomd.c,v 1.20 2012/05/14 11:05:29 skrll Exp $);
+__KERNEL_RCSID(0, $NetBSD: iomd.c,v 1.21 2012/10/10 22:00:22 skrll Exp $);
 
 #include sys/param.h
 #include sys/systm.h
@@ -156,7 +156,7 @@ iomdattach(device_t parent, device_t sel
 
 	/* Map the IOMD */
 	if (bus_space_map(iot, (int) iomd_base, IOMD_SIZE, 0, ioh))
-		panic(%s: Cannot map registers, self-dv_xname);
+		panic(%s: Cannot map registers, device_xname(self));
 
 	sc-sc_ioh = ioh;
 
@@ -191,7 +191,7 @@ iomdattach(device_t parent, device_t sel
 	aprint_normal(version %d\n, bus_space_read_1(iot, ioh, IOMD_VERSION));
 
 	/* Report the DRAM refresh rate */
-	aprint_normal(%s: , self-dv_xname);
+	aprint_normal(%s: , device_xname(self));
 	aprint_normal(DRAM refresh=);
 	switch (refresh) {
 	case 0x0:
@@ -221,7 +221,7 @@ iomdattach(device_t parent, device_t sel
 	 * attached
 	 */
 	tmp = bus_space_read_1(iot, ioh, IOMD_IOTCR);
-	aprint_normal(%s: I/O timings: combo %c, NPCCS1/2 %c, self-dv_xname,
+	aprint_normal(%s: I/O timings: combo %c, NPCCS1/2 %c, device_xname(self),
 	'A' + ((tmp 2)  3), 'A' + (tmp  3));
 	tmp = bus_space_read_1(iot, ioh, IOMD_ECTCR);
 	aprint_normal(, EASI );
@@ -257,7 +257,7 @@ iomdattach(device_t parent, device_t sel
 
 	/* Attach kbd device when configured */
 	if (bus_space_subregion(iot, ioh, IOMD_KBDDAT, 8, ia.ia_kbd.ka_ioh))
-		panic(%s: Cannot map kbd registers, self-dv_xname);
+		panic(%s: Cannot map kbd registers, device_xname(self));
 	ia.ia_kbd.ka_name = kbd;
 	ia.ia_kbd.ka_iot = iot;
 	ia.ia_kbd.ka_rxirq = IRQ_KBDRX;
@@ -267,7 +267,7 @@ iomdattach(device_t parent, device_t sel
 	/* Attach iic device */
 
 	if (bus_space_subregion(iot, ioh, IOMD_IOCR, 4, ia.ia_iic.ia_ioh))
-		panic(%s: Cannot map iic registers, self-dv_xname);
+		panic(%s: Cannot map iic registers, device_xname(self));
 	ia.ia_iic.ia_name = iic;
 	ia.ia_iic.ia_iot = iot;
 	ia.ia_iic.ia_irq = -1;
@@ -280,7 +280,7 @@ iomdattach(device_t parent, device_t sel
 
 		if (bus_space_subregion(iot, ioh, IOMD_MSDATA, 8,
 			ia.ia_opms.pa_ioh))
-			panic(%s: Cannot map opms registers, self-dv_xname);
+			panic(%s: Cannot map opms registers, device_xname(self));
 		ia.ia_opms.pa_name = opms;
 		ia.ia_opms.pa_iot = iot;
 		ia.ia_opms.pa_irq = IRQ_MSDRX;
@@ -291,10 +291,10 @@ iomdattach(device_t parent, device_t sel
 
 		if (bus_space_subregion(iot, ioh, IOMD_MOUSEX, 8,
 			ia.ia_qms.qa_ioh))
-			panic(%s: Cannot map qms registers, self-dv_xname);
+			panic(%s: Cannot map qms registers, device_xname(self));
 
 		if (bus_space_map(iot, IO_MOUSE_BUTTONS, 4, 0, ia.ia_qms.qa_ioh_but))
-			panic(%s: Cannot map registers, self-dv_xname);
+			panic(%s: Cannot map registers, device_xname(self));
 		ia.ia_qms.qa_name = qms;
 		ia.ia_qms.qa_iot = iot;
 		ia.ia_qms.qa_irq = IRQ_VSYNC;

Index: src/sys/arch/arm/iomd/vidcaudio.c
diff -u src/sys/arch/arm/iomd/vidcaudio.c:1.50 src/sys/arch/arm/iomd/vidcaudio.c:1.51
--- src/sys/arch/arm/iomd/vidcaudio.c:1.50	Mon May 14 10:38:08 2012
+++ src/sys/arch/arm/iomd/vidcaudio.c	Wed Oct 10 22:00:22 2012
@@ -1,4 +1,4 @@
-/*	$NetBSD: vidcaudio.c,v 1.50 2012/05/14 10:38:08 skrll Exp $	*/
+/*	$NetBSD: vidcaudio.c,v 1.51 2012/10/10 22:00:22 skrll Exp $	*/
 
 /*
  * Copyright (c) 1995 Melvin Tang-Richardson
@@ -65,7 +65,7 @@
 
 #include sys/param.h	/* proc.h */
 
-__KERNEL_RCSID(0, $NetBSD: vidcaudio.c,v 1.50 2012/05/14 10:38:08 skrll Exp $);
+__KERNEL_RCSID(0, $NetBSD: vidcaudio.c,v 1.51 2012/10/10 22:00:22 skrll Exp $);
 
 #include sys/audioio.h
 #include sys/conf.h   /* autoconfig functions */
@@ -253,11 +253,11 @@ vidcaudio_attach(device_t parent, device
 	sc-sc_ih.ih_func = vidcaudio_intr;
 	sc-sc_ih.ih_arg = sc;
 	sc-sc_ih.ih_level = IPL_AUDIO;
-	sc-sc_ih.ih_name = self-dv_xname;
+	sc-sc_ih.ih_name = device_xname(self);
 
 	if (irq_claim(sc-sc_dma_intr, sc-sc_ih) != 0) {
 		aprint_error(%s: couldn't claim IRQ %d\n,
-		self-dv_xname, sc-sc_dma_intr);
+		device_xname(self), sc-sc_dma_intr);
 		return;
 	}
 



CVS commit: src/sys/arch/arm/iomd

2012-05-18 Thread Nick Hudson
Module Name:src
Committed By:   skrll
Date:   Fri May 18 21:09:50 UTC 2012

Modified Files:
src/sys/arch/arm/iomd: iomd_clock.c

Log Message:
Replace a __cpu_simple_lock_t with a kmutex_t.


To generate a diff of this commit:
cvs rdiff -u -r1.28 -r1.29 src/sys/arch/arm/iomd/iomd_clock.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/arm/iomd/iomd_clock.c
diff -u src/sys/arch/arm/iomd/iomd_clock.c:1.28 src/sys/arch/arm/iomd/iomd_clock.c:1.29
--- src/sys/arch/arm/iomd/iomd_clock.c:1.28	Tue May 15 05:45:37 2012
+++ src/sys/arch/arm/iomd/iomd_clock.c	Fri May 18 21:09:50 2012
@@ -1,4 +1,4 @@
-/*	$NetBSD: iomd_clock.c,v 1.28 2012/05/15 05:45:37 skrll Exp $	*/
+/*	$NetBSD: iomd_clock.c,v 1.29 2012/05/18 21:09:50 skrll Exp $	*/
 
 /*
  * Copyright (c) 1994-1997 Mark Brinicombe.
@@ -47,7 +47,7 @@
 
 #include sys/param.h
 
-__KERNEL_RCSID(0, $NetBSD: iomd_clock.c,v 1.28 2012/05/15 05:45:37 skrll Exp $);
+__KERNEL_RCSID(0, $NetBSD: iomd_clock.c,v 1.29 2012/05/18 21:09:50 skrll Exp $);
 
 #include sys/systm.h
 #include sys/types.h
@@ -86,13 +86,12 @@ static void checkdelay(void);
 
 static u_int iomd_timecounter0_get(struct timecounter *tc);
 
-
 static volatile uint32_t timer0_lastcount;
 static volatile uint32_t timer0_offset;
 static volatile int timer0_ticked;
 /* TODO: Get IRQ status */
 
-static __cpu_simple_lock_t tmr_lock = __SIMPLELOCK_UNLOCKED;
+static kmutex_t tmr_lock;
 
 static struct timecounter iomd_timecounter = {
 	iomd_timecounter0_get,
@@ -144,9 +143,10 @@ clockattach(device_t parent, device_t se
 	sc-sc_ioh = ca-ca_ioh; /* This is a handle for the whole IOMD */
 
 	clock_sc = sc;
+	mutex_init(tmr_lock, MUTEX_DEFAULT, IPL_CLOCK);
 
 	/* Cannot do anything until cpu_initclocks() has been called */
-	
+
 	aprint_normal(\n);
 }
 
@@ -156,14 +156,14 @@ tickle_tc(void)
 {
 	if (timer0_count  
 	timecounter-tc_get_timecount == iomd_timecounter0_get) {
-		__cpu_simple_lock(tmr_lock);
+		mutex_spin_enter(tmr_lock);
 		if (timer0_ticked)
 			timer0_ticked= 0;
 		else {
 			timer0_offset   += timer0_count;
 			timer0_lastcount = 0;
 		}
-		__cpu_simple_unlock(tmr_lock);
+		mutex_spin_exit(tmr_lock);
 	}
 
 }
@@ -323,10 +323,9 @@ static u_int iomd_timecounter0_get(struc
 	tm += (bus_space_read_1(clock_sc-sc_iot, clock_sc-sc_ioh,
 	IOMD_T0HIGH)  8);
 	splx(s);
-	simple_lock(tmr_lock);
 
+	mutex_spin_enter(tmr_lock);
 	tm = timer0_count - tm;
-	
 
 	if (timer0_count 
 	(tm  timer0_lastcount || (!timer0_ticked  false/* XXX: clkintr_pending */))) {
@@ -336,8 +335,8 @@ static u_int iomd_timecounter0_get(struc
 
 	timer0_lastcount = tm;
 	tm += timer0_offset;
+	mutex_spin_exit(tmr_lock);
 
-	simple_unlock(tmr_lock);
 	return tm;
 }
 



CVS commit: src/sys/arch/arm/iomd

2012-05-14 Thread Nick Hudson
Module Name:src
Committed By:   skrll
Date:   Mon May 14 10:38:09 UTC 2012

Modified Files:
src/sys/arch/arm/iomd: iomd.c iomd_clock.c iomdiic.c iomdkbc.c qms.c
vidc20.c vidcaudio.c vidcvideo.c

Log Message:
device_t/softc split
struct device * - device_t
struct cfdata * - cfdata_t
Use aprint*


To generate a diff of this commit:
cvs rdiff -u -r1.18 -r1.19 src/sys/arch/arm/iomd/iomd.c
cvs rdiff -u -r1.26 -r1.27 src/sys/arch/arm/iomd/iomd_clock.c
cvs rdiff -u -r1.6 -r1.7 src/sys/arch/arm/iomd/iomdiic.c
cvs rdiff -u -r1.4 -r1.5 src/sys/arch/arm/iomd/iomdkbc.c
cvs rdiff -u -r1.17 -r1.18 src/sys/arch/arm/iomd/qms.c
cvs rdiff -u -r1.16 -r1.17 src/sys/arch/arm/iomd/vidc20.c
cvs rdiff -u -r1.49 -r1.50 src/sys/arch/arm/iomd/vidcaudio.c
cvs rdiff -u -r1.42 -r1.43 src/sys/arch/arm/iomd/vidcvideo.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/arm/iomd/iomd.c
diff -u src/sys/arch/arm/iomd/iomd.c:1.19 src/sys/arch/arm/iomd/iomd.c:1.20
--- src/sys/arch/arm/iomd/iomd.c:1.19	Mon May 14 10:38:08 2012
+++ src/sys/arch/arm/iomd/iomd.c	Mon May 14 11:05:29 2012
@@ -1,4 +1,4 @@
-/*	$NetBSD: iomd.c,v 1.19 2012/05/14 10:38:08 skrll Exp $	*/
+/*	$NetBSD: iomd.c,v 1.20 2012/05/14 11:05:29 skrll Exp $	*/
 
 /*
  * Copyright (c) 1996-1997 Mark Brinicombe.
@@ -43,7 +43,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: iomd.c,v 1.19 2012/05/14 10:38:08 skrll Exp $);
+__KERNEL_RCSID(0, $NetBSD: iomd.c,v 1.20 2012/05/14 11:05:29 skrll Exp $);
 
 #include sys/param.h
 #include sys/systm.h
@@ -74,7 +74,7 @@ __KERNEL_RCSID(0, $NetBSD: iomd.c,v 1.1
  */
 
 struct iomd_softc {
-	device_t	 		sc_dev;	/* device node */
+	device_t 		sc_dev;	/* device node */
 	bus_space_tag_t		sc_iot;	/* bus tag */
 	bus_space_handle_t	sc_ioh;	/* bus handle */
 	int			sc_id;	/* IOMD id */



CVS commit: src/sys/arch/arm/iomd

2012-05-14 Thread Nick Hudson
Module Name:src
Committed By:   skrll
Date:   Tue May 15 05:45:37 UTC 2012

Modified Files:
src/sys/arch/arm/iomd: iomd_clock.c

Log Message:
Typos in a comment.


To generate a diff of this commit:
cvs rdiff -u -r1.27 -r1.28 src/sys/arch/arm/iomd/iomd_clock.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/arm/iomd/iomd_clock.c
diff -u src/sys/arch/arm/iomd/iomd_clock.c:1.27 src/sys/arch/arm/iomd/iomd_clock.c:1.28
--- src/sys/arch/arm/iomd/iomd_clock.c:1.27	Mon May 14 10:38:08 2012
+++ src/sys/arch/arm/iomd/iomd_clock.c	Tue May 15 05:45:37 2012
@@ -1,4 +1,4 @@
-/*	$NetBSD: iomd_clock.c,v 1.27 2012/05/14 10:38:08 skrll Exp $	*/
+/*	$NetBSD: iomd_clock.c,v 1.28 2012/05/15 05:45:37 skrll Exp $	*/
 
 /*
  * Copyright (c) 1994-1997 Mark Brinicombe.
@@ -47,7 +47,7 @@
 
 #include sys/param.h
 
-__KERNEL_RCSID(0, $NetBSD: iomd_clock.c,v 1.27 2012/05/14 10:38:08 skrll Exp $);
+__KERNEL_RCSID(0, $NetBSD: iomd_clock.c,v 1.28 2012/05/15 05:45:37 skrll Exp $);
 
 #include sys/systm.h
 #include sys/types.h
@@ -312,7 +312,7 @@ static u_int iomd_timecounter0_get(struc
 
 	/*
 	 * Latch the current value of the timer and then read it.
-	 * This garentees an atmoic reading of the time.
+	 * This guarantees an atomic reading of the time.
 	 */
 	s = splhigh();
 	bus_space_write_1(clock_sc-sc_iot, clock_sc-sc_ioh,



CVS commit: src/sys/arch/arm/iomd

2012-05-10 Thread Nick Hudson
Module Name:src
Committed By:   skrll
Date:   Thu May 10 07:39:48 UTC 2012

Modified Files:
src/sys/arch/arm/iomd: vidcaudio.c

Log Message:
KNF


To generate a diff of this commit:
cvs rdiff -u -r1.48 -r1.49 src/sys/arch/arm/iomd/vidcaudio.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/arm/iomd/vidcaudio.c
diff -u src/sys/arch/arm/iomd/vidcaudio.c:1.48 src/sys/arch/arm/iomd/vidcaudio.c:1.49
--- src/sys/arch/arm/iomd/vidcaudio.c:1.48	Thu Nov 24 03:35:56 2011
+++ src/sys/arch/arm/iomd/vidcaudio.c	Thu May 10 07:39:48 2012
@@ -1,4 +1,4 @@
-/*	$NetBSD: vidcaudio.c,v 1.48 2011/11/24 03:35:56 mrg Exp $	*/
+/*	$NetBSD: vidcaudio.c,v 1.49 2012/05/10 07:39:48 skrll Exp $	*/
 
 /*
  * Copyright (c) 1995 Melvin Tang-Richardson
@@ -65,7 +65,7 @@
 
 #include sys/param.h	/* proc.h */
 
-__KERNEL_RCSID(0, $NetBSD: vidcaudio.c,v 1.48 2011/11/24 03:35:56 mrg Exp $);
+__KERNEL_RCSID(0, $NetBSD: vidcaudio.c,v 1.49 2012/05/10 07:39:48 skrll Exp $);
 
 #include sys/audioio.h
 #include sys/conf.h   /* autoconfig functions */
@@ -478,7 +478,8 @@ vidcaudio_trigger_output(void *addr, voi
 	if (sc-sc_ppages != NULL)
 		free(sc-sc_ppages, M_DEVBUF);
 	sc-sc_ppages = malloc(npages * sizeof(paddr_t), M_DEVBUF, M_WAITOK);
-	if (sc-sc_ppages == NULL) return ENOMEM;
+	if (sc-sc_ppages == NULL)
+		return ENOMEM;
 	for (i = 0; i  npages; i++)
 		if (!pmap_extract(pmap_kernel(),
 		(vaddr_t)start + i * PAGE_SIZE, sc-sc_ppages[i]))



CVS commit: src/sys/arch/arm/iomd

2012-05-10 Thread Nick Hudson
Module Name:src
Committed By:   skrll
Date:   Thu May 10 09:56:27 UTC 2012

Modified Files:
src/sys/arch/arm/iomd: iomd.c iomdvar.h qms.c vidcvideo.c

Log Message:
u_int*_t - uint*_t


To generate a diff of this commit:
cvs rdiff -u -r1.17 -r1.18 src/sys/arch/arm/iomd/iomd.c
cvs rdiff -u -r1.3 -r1.4 src/sys/arch/arm/iomd/iomdvar.h
cvs rdiff -u -r1.16 -r1.17 src/sys/arch/arm/iomd/qms.c
cvs rdiff -u -r1.41 -r1.42 src/sys/arch/arm/iomd/vidcvideo.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/arm/iomd/iomd.c
diff -u src/sys/arch/arm/iomd/iomd.c:1.17 src/sys/arch/arm/iomd/iomd.c:1.18
--- src/sys/arch/arm/iomd/iomd.c:1.17	Fri Jul  1 20:26:35 2011
+++ src/sys/arch/arm/iomd/iomd.c	Thu May 10 09:56:27 2012
@@ -1,4 +1,4 @@
-/*	$NetBSD: iomd.c,v 1.17 2011/07/01 20:26:35 dyoung Exp $	*/
+/*	$NetBSD: iomd.c,v 1.18 2012/05/10 09:56:27 skrll Exp $	*/
 
 /*
  * Copyright (c) 1996-1997 Mark Brinicombe.
@@ -43,7 +43,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: iomd.c,v 1.17 2011/07/01 20:26:35 dyoung Exp $);
+__KERNEL_RCSID(0, $NetBSD: iomd.c,v 1.18 2012/05/10 09:56:27 skrll Exp $);
 
 #include sys/param.h
 #include sys/systm.h
@@ -92,10 +92,10 @@ CFATTACH_DECL(iomd, sizeof(struct iomd_s
 extern struct bus_space iomd_bs_tag;
 
 int   iomd_found;
-u_int32_t iomd_base = IOMD_BASE;
+uint32_t iomd_base = IOMD_BASE;
 
 /* following flag is used in iomd_irq.s ... has to be cleaned up one day ! */
-u_int32_t arm7500_ioc_found = 0;
+uint32_t arm7500_ioc_found = 0;
 
 
 /* Declare prototypes */

Index: src/sys/arch/arm/iomd/iomdvar.h
diff -u src/sys/arch/arm/iomd/iomdvar.h:1.3 src/sys/arch/arm/iomd/iomdvar.h:1.4
--- src/sys/arch/arm/iomd/iomdvar.h:1.3	Fri Jul  1 20:26:35 2011
+++ src/sys/arch/arm/iomd/iomdvar.h	Thu May 10 09:56:27 2012
@@ -1,4 +1,4 @@
-/*	$NetBSD: iomdvar.h,v 1.3 2011/07/01 20:26:35 dyoung Exp $	*/
+/*	$NetBSD: iomdvar.h,v 1.4 2012/05/10 09:56:27 skrll Exp $	*/
 
 /*
  * Copyright (c) 1997 Mark Brinicombe.
@@ -119,6 +119,6 @@ union iomd_attach_args {
 /*
  * IOMD_BASE register variable
  */
-extern u_int32_t iomd_base;
+extern uint32_t iomd_base;
 
 /* End of iomdvar.h */

Index: src/sys/arch/arm/iomd/qms.c
diff -u src/sys/arch/arm/iomd/qms.c:1.16 src/sys/arch/arm/iomd/qms.c:1.17
--- src/sys/arch/arm/iomd/qms.c:1.16	Fri Jul  1 20:26:35 2011
+++ src/sys/arch/arm/iomd/qms.c	Thu May 10 09:56:27 2012
@@ -1,4 +1,4 @@
-/*	$NetBSD: qms.c,v 1.16 2011/07/01 20:26:35 dyoung Exp $	*/
+/*	$NetBSD: qms.c,v 1.17 2012/05/10 09:56:27 skrll Exp $	*/
 
 /*-
  * Copyright (c) 2001 Reinoud Zandijk
@@ -41,7 +41,7 @@
 
 #include sys/param.h
 
-__KERNEL_RCSID(0, $NetBSD: qms.c,v 1.16 2011/07/01 20:26:35 dyoung Exp $);
+__KERNEL_RCSID(0, $NetBSD: qms.c,v 1.17 2012/05/10 09:56:27 skrll Exp $);
 
 #include sys/callout.h
 #include sys/device.h
@@ -74,8 +74,8 @@ struct qms_softc {
 
 	struct callout sc_callout;
 
-	u_int16_t lastx;
-	u_int16_t lasty;
+	uint16_t lastx;
+	uint16_t lasty;
 	int lastb;
 };
 
@@ -184,7 +184,7 @@ qms_intr(void *arg)
 {
 	struct qms_softc *sc = arg;
 	int b;
-	u_int16_t x, y;
+	uint16_t x, y;
 	int16_t dx, dy;
 
 	x = bus_space_read_4(sc-sc_iot, sc-sc_ioh, QMS_MOUSEX);

Index: src/sys/arch/arm/iomd/vidcvideo.c
diff -u src/sys/arch/arm/iomd/vidcvideo.c:1.41 src/sys/arch/arm/iomd/vidcvideo.c:1.42
--- src/sys/arch/arm/iomd/vidcvideo.c:1.41	Tue Feb 14 14:33:53 2012
+++ src/sys/arch/arm/iomd/vidcvideo.c	Thu May 10 09:56:27 2012
@@ -1,4 +1,4 @@
-/* $NetBSD: vidcvideo.c,v 1.41 2012/02/14 14:33:53 skrll Exp $ */
+/* $NetBSD: vidcvideo.c,v 1.42 2012/05/10 09:56:27 skrll Exp $ */
 
 /*
  * Copyright (c) 2001 Reinoud Zandijk
@@ -30,7 +30,7 @@
 
 #include sys/cdefs.h			/* RCS ID  Copyright macro defns */
 
-__KERNEL_RCSID(0, $NetBSD: vidcvideo.c,v 1.41 2012/02/14 14:33:53 skrll Exp $);
+__KERNEL_RCSID(0, $NetBSD: vidcvideo.c,v 1.42 2012/05/10 09:56:27 skrll Exp $);
 
 #include sys/param.h
 #include sys/systm.h
@@ -607,7 +607,7 @@ vidcvideo_colourmap_and_cursor_init(stru
 	struct rasops_info *ri = dc-dc_console.scr_ri;
 	const u_char *rgbdat;
 	struct hwcmap256 *cm;
-	const u_int8_t *p;
+	const uint8_t *p;
 	int index;
 
 	/* Whatever we do later... just make sure we have a
@@ -718,7 +718,7 @@ set_cursor(struct vidcvideo_softc *sc, s
 		if (p-size.x  CURSOR_MAX_WIDTH ||
 		p-size.y  CURSOR_MAX_HEIGHT)
 			return EINVAL;
-		icount = sizeof(u_int32_t) * p-size.y;
+		icount = sizeof(uint32_t) * p-size.y;
 		error = copyin(p-image, image, icount);
 		if (error)
 			return error;



CVS commit: src/sys/arch/arm/iomd

2012-02-14 Thread Nick Hudson
Module Name:src
Committed By:   skrll
Date:   Tue Feb 14 13:04:52 UTC 2012

Modified Files:
src/sys/arch/arm/iomd: vidcvideo.c

Log Message:
Pass RI_NO_AUTO to rasops_init so that rasops doesn't attempt to allocate
memory as we're too early in kernel startup for this.

My A7000 boots now.

OK releng. ack 3 nak 0.


To generate a diff of this commit:
cvs rdiff -u -r1.39 -r1.40 src/sys/arch/arm/iomd/vidcvideo.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/arm/iomd/vidcvideo.c
diff -u src/sys/arch/arm/iomd/vidcvideo.c:1.39 src/sys/arch/arm/iomd/vidcvideo.c:1.40
--- src/sys/arch/arm/iomd/vidcvideo.c:1.39	Fri Jul  1 20:26:35 2011
+++ src/sys/arch/arm/iomd/vidcvideo.c	Tue Feb 14 13:04:51 2012
@@ -1,4 +1,4 @@
-/* $NetBSD: vidcvideo.c,v 1.39 2011/07/01 20:26:35 dyoung Exp $ */
+/* $NetBSD: vidcvideo.c,v 1.40 2012/02/14 13:04:51 skrll Exp $ */
 
 /*
  * Copyright (c) 2001 Reinoud Zandijk
@@ -30,7 +30,7 @@
 
 #include sys/cdefs.h			/* RCS ID  Copyright macro defns */
 
-__KERNEL_RCSID(0, $NetBSD: vidcvideo.c,v 1.39 2011/07/01 20:26:35 dyoung Exp $);
+__KERNEL_RCSID(0, $NetBSD: vidcvideo.c,v 1.40 2012/02/14 13:04:51 skrll Exp $);
 
 #include sys/param.h
 #include sys/systm.h
@@ -267,7 +267,7 @@ vidcvideoinit_screen(void *cookie, struc
 	if ((scr == dc-dc_console)  (dc-dc_vd.active != NULL))
 		return;
 
-	ri-ri_flg= 0; /* RI_CENTER | RI_FULLCLEAR; */
+	ri-ri_flg= RI_NO_AUTO ; /* RI_CENTER | RI_FULLCLEAR; */
 	ri-ri_depth  = dc-dc_depth;
 	ri-ri_bits   = (void *) dc-dc_videobase;
 	ri-ri_width  = dc-dc_width;



CVS commit: src/sys/arch/arm/iomd

2012-02-14 Thread Nick Hudson
Module Name:src
Committed By:   skrll
Date:   Tue Feb 14 14:33:54 UTC 2012

Modified Files:
src/sys/arch/arm/iomd: vidcvideo.c

Log Message:
Whitespace in previous.

Ride previous releng OK.


To generate a diff of this commit:
cvs rdiff -u -r1.40 -r1.41 src/sys/arch/arm/iomd/vidcvideo.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/arm/iomd/vidcvideo.c
diff -u src/sys/arch/arm/iomd/vidcvideo.c:1.40 src/sys/arch/arm/iomd/vidcvideo.c:1.41
--- src/sys/arch/arm/iomd/vidcvideo.c:1.40	Tue Feb 14 13:04:51 2012
+++ src/sys/arch/arm/iomd/vidcvideo.c	Tue Feb 14 14:33:53 2012
@@ -1,4 +1,4 @@
-/* $NetBSD: vidcvideo.c,v 1.40 2012/02/14 13:04:51 skrll Exp $ */
+/* $NetBSD: vidcvideo.c,v 1.41 2012/02/14 14:33:53 skrll Exp $ */
 
 /*
  * Copyright (c) 2001 Reinoud Zandijk
@@ -30,7 +30,7 @@
 
 #include sys/cdefs.h			/* RCS ID  Copyright macro defns */
 
-__KERNEL_RCSID(0, $NetBSD: vidcvideo.c,v 1.40 2012/02/14 13:04:51 skrll Exp $);
+__KERNEL_RCSID(0, $NetBSD: vidcvideo.c,v 1.41 2012/02/14 14:33:53 skrll Exp $);
 
 #include sys/param.h
 #include sys/systm.h
@@ -267,7 +267,7 @@ vidcvideoinit_screen(void *cookie, struc
 	if ((scr == dc-dc_console)  (dc-dc_vd.active != NULL))
 		return;
 
-	ri-ri_flg= RI_NO_AUTO ; /* RI_CENTER | RI_FULLCLEAR; */
+	ri-ri_flg= RI_NO_AUTO;	/* RI_CENTER | RI_FULLCLEAR; */
 	ri-ri_depth  = dc-dc_depth;
 	ri-ri_bits   = (void *) dc-dc_videobase;
 	ri-ri_width  = dc-dc_width;



CVS commit: src/sys/arch/arm/iomd

2011-07-01 Thread David Young
Module Name:src
Committed By:   dyoung
Date:   Fri Jul  1 20:26:36 UTC 2011

Modified Files:
src/sys/arch/arm/iomd: iomd.c iomd_io.c iomdkbc.c iomdvar.h qms.c
vidc20.c vidcvideo.c
src/sys/arch/arm/iomd/console: consinit.c

Log Message:
#include sys/bus.h instead of machine/bus.h.


To generate a diff of this commit:
cvs rdiff -u -r1.16 -r1.17 src/sys/arch/arm/iomd/iomd.c
cvs rdiff -u -r1.5 -r1.6 src/sys/arch/arm/iomd/iomd_io.c
cvs rdiff -u -r1.3 -r1.4 src/sys/arch/arm/iomd/iomdkbc.c
cvs rdiff -u -r1.2 -r1.3 src/sys/arch/arm/iomd/iomdvar.h
cvs rdiff -u -r1.15 -r1.16 src/sys/arch/arm/iomd/qms.c \
src/sys/arch/arm/iomd/vidc20.c
cvs rdiff -u -r1.38 -r1.39 src/sys/arch/arm/iomd/vidcvideo.c
cvs rdiff -u -r1.7 -r1.8 src/sys/arch/arm/iomd/console/consinit.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/arm/iomd/iomd.c
diff -u src/sys/arch/arm/iomd/iomd.c:1.16 src/sys/arch/arm/iomd/iomd.c:1.17
--- src/sys/arch/arm/iomd/iomd.c:1.16	Thu Jun 30 20:09:20 2011
+++ src/sys/arch/arm/iomd/iomd.c	Fri Jul  1 20:26:35 2011
@@ -1,4 +1,4 @@
-/*	$NetBSD: iomd.c,v 1.16 2011/06/30 20:09:20 wiz Exp $	*/
+/*	$NetBSD: iomd.c,v 1.17 2011/07/01 20:26:35 dyoung Exp $	*/
 
 /*
  * Copyright (c) 1996-1997 Mark Brinicombe.
@@ -43,7 +43,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: iomd.c,v 1.16 2011/06/30 20:09:20 wiz Exp $);
+__KERNEL_RCSID(0, $NetBSD: iomd.c,v 1.17 2011/07/01 20:26:35 dyoung Exp $);
 
 #include sys/param.h
 #include sys/systm.h
@@ -51,7 +51,7 @@
 #include sys/conf.h
 #include sys/malloc.h
 #include sys/device.h
-#include machine/bus.h
+#include sys/bus.h
 #include machine/cpu.h
 #include machine/intr.h
 #include arm/iomd/iomdreg.h

Index: src/sys/arch/arm/iomd/iomd_io.c
diff -u src/sys/arch/arm/iomd/iomd_io.c:1.5 src/sys/arch/arm/iomd/iomd_io.c:1.6
--- src/sys/arch/arm/iomd/iomd_io.c:1.5	Sat Aug  5 18:22:57 2006
+++ src/sys/arch/arm/iomd/iomd_io.c	Fri Jul  1 20:26:35 2011
@@ -1,4 +1,4 @@
-/*	$NetBSD: iomd_io.c,v 1.5 2006/08/05 18:22:57 bjh21 Exp $	*/
+/*	$NetBSD: iomd_io.c,v 1.6 2011/07/01 20:26:35 dyoung Exp $	*/
 
 /*
  * Copyright (c) 1997 Mark Brinicombe.
@@ -38,11 +38,11 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: iomd_io.c,v 1.5 2006/08/05 18:22:57 bjh21 Exp $);
+__KERNEL_RCSID(0, $NetBSD: iomd_io.c,v 1.6 2011/07/01 20:26:35 dyoung Exp $);
 
 #include sys/param.h
 #include sys/systm.h
-#include machine/bus.h
+#include sys/bus.h
 
 /* Proto types for all the bus_space structure functions */
 

Index: src/sys/arch/arm/iomd/iomdkbc.c
diff -u src/sys/arch/arm/iomd/iomdkbc.c:1.3 src/sys/arch/arm/iomd/iomdkbc.c:1.4
--- src/sys/arch/arm/iomd/iomdkbc.c:1.3	Sat Oct 21 22:45:03 2006
+++ src/sys/arch/arm/iomd/iomdkbc.c	Fri Jul  1 20:26:35 2011
@@ -1,4 +1,4 @@
-/* $NetBSD: iomdkbc.c,v 1.3 2006/10/21 22:45:03 bjh21 Exp $ */
+/* $NetBSD: iomdkbc.c,v 1.4 2011/07/01 20:26:35 dyoung Exp $ */
 
 /*-
  * Copyright (c) 2004 Ben Harris
@@ -28,7 +28,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: iomdkbc.c,v 1.3 2006/10/21 22:45:03 bjh21 Exp $);
+__KERNEL_RCSID(0, $NetBSD: iomdkbc.c,v 1.4 2011/07/01 20:26:35 dyoung Exp $);
 
 #include sys/param.h
 #include sys/device.h
@@ -37,7 +37,7 @@
 
 #include dev/pckbport/pckbportvar.h
 
-#include machine/bus.h
+#include sys/bus.h
 #include machine/intr.h
 
 #include arch/arm/iomd/iomdreg.h

Index: src/sys/arch/arm/iomd/iomdvar.h
diff -u src/sys/arch/arm/iomd/iomdvar.h:1.2 src/sys/arch/arm/iomd/iomdvar.h:1.3
--- src/sys/arch/arm/iomd/iomdvar.h:1.2	Fri Apr 19 01:04:39 2002
+++ src/sys/arch/arm/iomd/iomdvar.h	Fri Jul  1 20:26:35 2011
@@ -1,4 +1,4 @@
-/*	$NetBSD: iomdvar.h,v 1.2 2002/04/19 01:04:39 wiz Exp $	*/
+/*	$NetBSD: iomdvar.h,v 1.3 2011/07/01 20:26:35 dyoung Exp $	*/
 
 /*
  * Copyright (c) 1997 Mark Brinicombe.
@@ -39,7 +39,7 @@
  * Created  : 02/02/97
  */
 
-#include machine/bus.h
+#include sys/bus.h
 
 /*
  * Attach args for iomd_clock device

Index: src/sys/arch/arm/iomd/qms.c
diff -u src/sys/arch/arm/iomd/qms.c:1.15 src/sys/arch/arm/iomd/qms.c:1.16
--- src/sys/arch/arm/iomd/qms.c:1.15	Sat May 10 15:31:04 2008
+++ src/sys/arch/arm/iomd/qms.c	Fri Jul  1 20:26:35 2011
@@ -1,4 +1,4 @@
-/*	$NetBSD: qms.c,v 1.15 2008/05/10 15:31:04 martin Exp $	*/
+/*	$NetBSD: qms.c,v 1.16 2011/07/01 20:26:35 dyoung Exp $	*/
 
 /*-
  * Copyright (c) 2001 Reinoud Zandijk
@@ -41,7 +41,7 @@
 
 #include sys/param.h
 
-__KERNEL_RCSID(0, $NetBSD: qms.c,v 1.15 2008/05/10 15:31:04 martin Exp $);
+__KERNEL_RCSID(0, $NetBSD: qms.c,v 1.16 2011/07/01 20:26:35 dyoung Exp $);
 
 #include sys/callout.h
 #include sys/device.h
@@ -56,7 +56,7 @@
 #include sys/systm.h
 #include sys/select.h
 
-#include machine/bus.h
+#include sys/bus.h
 #include machine/intr.h
 
 #include arm/iomd/iomdvar.h
Index: src/sys/arch/arm/iomd/iomd.c
diff -u src/sys/arch/arm/iomd/iomd.c:1.18 src/sys/arch/arm/iomd/iomd.c:1.19
--- src/sys/arch/arm/iomd/iomd.c:1.18	Thu May 10 09:56:27 2012
+++ src/sys/arch/arm/iomd/iomd.c	Mon May 14 10:38:08 2012
@@ -1,4 +1,4 @@
-/*	$NetBSD: iomd.c,v 1.18 2012/05/10 09:56:27 skrll Exp $	*/
+/*	$NetBSD: iomd.c,v 1.19 2012/05/14 10:38:08 skrll Exp $	*/
 
 /*
  * Copyright (c) 1996-1997 Mark Brinicombe.
@@ -43,7 +43,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: iomd.c,v 1.18 2012/05/10 09:56:27 skrll Exp $);
+__KERNEL_RCSID(0, $NetBSD: iomd.c,v 1.19 2012/05/14 10:38:08 skrll Exp $);
 
 #include sys/param.h
 #include sys/systm.h
@@ -74,19 +74,17 @@ __KERNEL_RCSID(0, $NetBSD: iomd.c,v 1.1
  */
 
 struct iomd_softc {
-	struct device 		sc_dev;	/* device node */
+	device_t	 		sc_dev;	/* device node */
 	bus_space_tag_t		sc_iot;	/* bus tag */
 	bus_space_handle_t	sc_ioh;	/* bus handle */
 	int			sc_id;	/* IOMD id */
 };
 
-static int iomdmatch(struct device *parent, struct cfdata *cf,
- void *aux);
-static void iomdattach(struct device *parent, struct device *self,
- void *aux);
+static int iomdmatch(device_t parent, cfdata_t cf, void *aux);
+static void iomdattach(device_t parent, device_t self, void *aux);
 static int iomdprint(void *aux, const char *iomdbus);
 
-CFATTACH_DECL(iomd, sizeof(struct iomd_softc),
+CFATTACH_DECL_NEW(iomd, sizeof(struct iomd_softc),
 iomdmatch, iomdattach, NULL, NULL);
 
 extern struct bus_space iomd_bs_tag;
@@ -115,13 +113,13 @@ iomdprint(void *aux, const char *name)
 }
 
 /*
  * int iomdmatch(struct device *parent, struct cfdata *cf, void *aux)
  *
  * Just return ok for this if it is device 0
  */ 
  
 static int
-iomdmatch(struct device *parent, struct cfdata *cf, void *aux)
+iomdmatch(device_t parent, cfdata_t cf, void *aux)
 {
 
 	if (iomd_found)
@@ -131,16 +129,16 @@ iomdmatch(struct device *parent, struct 
 
 
 /*
  * void iomdattach(struct device *parent, struct device *dev, void *aux)
  *
  * Map the IOMD and identify it.
  * Then configure the child devices based on the IOMD ID.
  */
   
 static void
-iomdattach(struct device *parent, struct device *self, void *aux)
+iomdattach(device_t parent, device_t self, void *aux)
 {
-	struct iomd_softc *sc = (struct iomd_softc *)self;
+	struct iomd_softc *sc = device_private(self);
 /*	struct mainbus_attach_args *mb = aux;*/
 	int refresh;
 #if 0
@@ -153,6 +151,7 @@ iomdattach(struct device *parent, struct
 	/* There can be only 1 IOMD. */
 	iomd_found = 1;
 
+	sc-sc_dev = self;
 	iot = sc-sc_iot = iomd_bs_tag;
 
 	/* Map the IOMD */
@@ -164,75 +163,75 @@ iomdattach(struct device *parent, struct
 	/* Get the ID */
 	sc-sc_id = bus_space_read_1(iot, ioh, IOMD_ID0)
 		  | (bus_space_read_1(iot, ioh, IOMD_ID1)  8);
-	printf(: );
+	aprint_normal(: );
 
 	/* Identify it and get the DRAM refresh rate */
 	switch (sc-sc_id) {
 	case ARM7500_IOC_ID:
-		printf(ARM7500 IOMD );
+		aprint_normal(ARM7500 IOMD );
 		refresh = bus_space_read_1(iot, ioh, IOMD_REFCR)  0x0f;
 		arm7500_ioc_found = 1;
 		break;
 	case ARM7500FE_IOC_ID:
-		printf(ARM7500FE IOMD );
+		aprint_normal(ARM7500FE IOMD );
 		refresh = bus_space_read_1(iot, ioh, IOMD_REFCR)  0x0f;
 		arm7500_ioc_found = 1;
 		break;
 	case RPC600_IOMD_ID:
-		printf(IOMD20 );
+		aprint_normal(IOMD20 );
 		refresh = bus_space_read_1(iot, ioh, IOMD_VREFCR)  0x09;
 		arm7500_ioc_found = 0;
 		break;
 	default:
-		printf(Unknown IOMD ID=%04x , sc-sc_id);
+		aprint_normal(Unknown IOMD ID=%04x , sc-sc_id);
 		refresh = -1;
 		arm7500_ioc_found = 0;		/* just in case */
 		break;
 	}
-	printf(version %d\n, bus_space_read_1(iot, ioh, IOMD_VERSION));
+	aprint_normal(version %d\n, bus_space_read_1(iot, ioh, IOMD_VERSION));
 
 	/* Report the DRAM refresh rate */
-	printf(%s: , self-dv_xname);
-	printf(DRAM refresh=);
+	aprint_normal(%s: , 
@@ -115,13 +113,13 @@ iomdprint(void *aux, const char *name)
 
 /*
- * int iomdmatch(struct device *parent, struct cfdata *cf, void *aux)
+ * int iomdmatch(device_t parent, cfdata_t cf, void *aux)
  *
  * Just return ok for this if it is device 0
@@ -131,16 +129,16 @@ iomdmatch(struct device *parent, struct 
 
 /*
- * void iomdattach(struct device *parent, struct device *dev, void *aux)
+ * void iomdattach(device_t parent, device_t dev, void *aux)
  *
  * Map the IOMD and identify it.

CVS commit: src/sys/arch/arm/iomd

2012-05-14 Thread Nick Hudson
Module Name:src
Committed By:   skrll
Date:   Mon May 14 11:05:29 UTC 2012

Modified Files:
src/sys/arch/arm/iomd: iomd.c

Log Message:
Whitespace in previous.


To generate a diff of this commit:
cvs rdiff -u -r1.19 -r1.20 src/sys/arch/arm/iomd/iomd.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/arm/iomd/vidc20.c
diff -u src/sys/arch/arm/iomd/vidc20.c:1.15 src/sys/arch/arm/iomd/vidc20.c:1.16
---